==> kenga-0.0.51.tgz: package/font.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var _createClass = require('@babel/runtime/helpers/createClass');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var _createClass__default = /*#__PURE__*/_interopDefaultLegacy(_createClass);

var Style = {
  NORMAL: 'normal',
  BOLD: 'bold',
  ITALIC: 'italic',
  BOLD_ITALIC: 'bold-italic'
};

var Font = /*#__PURE__*/function () {
  function Font(family, style, size) {
    _classCallCheck__default['default'](this, Font);

    var self = this;
    Object.defineProperty(self, 'family', {
      get: function get() {
        return family;
      }
    });
    Object.defineProperty(self, 'style', {
      get: function get() {
        return style;
      }
    });
    Object.defineProperty(self, 'size', {
      get: function get() {
        return size;
      }
    });
    Object.defineProperty(self, 'bold', {
      get: function get() {
        return style === Style.BOLD || style === Style.BOLD_ITALIC;
      }
    });
    Object.defineProperty(self, 'italic', {
      get: function get() {
        return Style === Style.ITALIC || style === Style.BOLD_ITALIC;
      }
    });
  }

  _createClass__default['default'](Font, [{
    key: "toString",
    value: function toString() {
      return "".concat(this.family, " ").concat(this.style === Style.ITALIC ? 'Italic' : this.style === Style.BOLD ? 'Bold' : this.style === Style.BOLD_ITALIC ? 'Bold Italic' : 'Normal', " ").concat(this.size);
    }
  }]);

  return Font;
}();

Object.defineProperty(Font, 'Style', {
  get: function get() {
    return Style;
  }
});

module.exports = Font;

==> kenga-0.0.53.tgz: package/font.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var _createClass = require('@babel/runtime/helpers/createClass');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var _createClass__default = /*#__PURE__*/_interopDefaultLegacy(_createClass);

var Style = {
  NORMAL: 'normal',
  BOLD: 'bold',
  ITALIC: 'italic',
  BOLD_ITALIC: 'bold-italic'
};

var Font = /*#__PURE__*/function () {
  function Font(family, style, size) {
    _classCallCheck__default["default"](this, Font);

    var self = this;
    Object.defineProperty(self, 'family', {
      get: function get() {
        return family;
      }
    });
    Object.defineProperty(self, 'style', {
      get: function get() {
        return style;
      }
    });
    Object.defineProperty(self, 'size', {
      get: function get() {
        return size;
      }
    });
    Object.defineProperty(self, 'bold', {
      get: function get() {
        return style === Style.BOLD || style === Style.BOLD_ITALIC;
      }
    });
    Object.defineProperty(self, 'italic', {
      get: function get() {
        return Style === Style.ITALIC || style === Style.BOLD_ITALIC;
      }
    });
  }

  _createClass__default["default"](Font, [{
    key: "toString",
    value: function toString() {
      return "".concat(this.family, " ").concat(this.style === Style.ITALIC ? 'Italic' : this.style === Style.BOLD ? 'Bold' : this.style === Style.BOLD_ITALIC ? 'Bold Italic' : 'Normal', " ").concat(this.size);
    }
  }]);

  return Font;
}();

Object.defineProperty(Font, 'Style', {
  get: function get() {
    return Style;
  }
});

module.exports = Font;
